@@ -70,13 +70,17 @@ lav_fit_measures <- function(object, fit.measures = "all",
 
     # Change 0.5-13: take into account explicit equality constraints!!
     # reported by Mark L. Taper (affects AIC and BIC)
-    npar <- object@optim$npar
+    #npar <- object@optim$npar
+    npar <- lav_partable_npar(object@ParTable)
     if(nrow(object@Model@con.jac) > 0L) {
         ceq.idx <- attr(object@Model@con.jac, "ceq.idx")
         if(length(ceq.idx) > 0L) {
             neq <- qr(object@Model@con.jac[ceq.idx,,drop=FALSE])$rank
             npar <- npar - neq
         }
+    } else if(.hasSlot(object@Model, "ceq.simple.only") &&
+              object@Model@ceq.simple.only) {
+        npar <- max(object@ParTable$free)
     }
 
     fx <- object@optim$fx
@@ -218,6 +222,11 @@ lav_fit_measures <- function(object, fit.measures = "all",
     # various
     if(object@Data@nlevels > 1L) {
         fit.other <- ""
+    } else if(estimator == "PML") {
+        fit.other <- c("cn_05","cn_01","mfi")
+        if(!categorical && G == 1) {
+            fit.other <- c(fit.other, "ecvi")
+        }
     } else {
         fit.other <- c("cn_05","cn_01","gfi","agfi","pgfi","mfi")
         if(!categorical && G == 1) {
@@ -854,7 +863,8 @@ lav_fit_measures <- function(object, fit.measures = "all",
         if(is.na(XX2) || is.na(df2)) {
             indices["rmsea.ci.lower.scaled"] <-
             indices["rmsea.ci.lower.robust"] <- NA
-        } else if(df < 1 || df2 < 1 || lower.lambda(0) < 0.0) {
+        #} else if(df < 1 || df2 < 1 || lower.lambda(0) < 0.0) {
+        } else if(df < 1 || lower.lambda(0) < 0.0) { # no longer df2<1 check
             indices["rmsea.ci.lower.scaled"] <-
             indices["rmsea.ci.lower.robust"] <- 0
         } else {
@@ -932,8 +942,8 @@ lav_fit_measures <- function(object, fit.measures = "all",
         if(is.na(XX2) || is.na(df2)) {
             indices["rmsea.ci.upper.scaled"] <-
             indices["rmsea.ci.upper.robust"] <- NA
-        } else if(df < 1 || df2 < 1 || upper.lambda(N.RMSEA) > 0 ||
-                                       upper.lambda(0) < 0) {
+        } else if(df < 1 || upper.lambda(N.RMSEA) > 0 ||
+                            upper.lambda(0) < 0) {
             indices["rmsea.ci.upper.scaled"] <-
             indices["rmsea.ci.upper.robust"] <- 0
         } else {
