@@ -485,17 +485,18 @@ lav_object_print_sam_test_statistics <- function(object, nd = 3L) {
             class(tmp) <- c("lavaan.data.frame", "data.frame")
             print(tmp, row.names = rep(" ", nrow(tmp)), nd = nd)
         } else {
-            cat("  Model-based reliability latent variables (per group):\n\n")
             cat("\n")
+            cat("  Model-based reliability latent variables (per group):\n")
             for(g in 1:object@Data@ngroups) {
+                cat("\n")
+                cat("  Group ", g, " [", object@Data@group.label[g], "]:\n\n",
+                    sep = "")
                 tmp <- data.frame(as.list(object@internal$sam.mm.rel[[g]]))
                 class(tmp) <- c("lavaan.data.frame", "data.frame")
                 print(tmp, row.names = rep(" ", nrow(tmp)), nd = nd)
-                #print(c(NA,round(object@internal$sam.mm.rel[[g]], 3)),
-                #  na.print = "")
             }
         }
-    
+
         cat("\n")
         cat("  Summary Information Structural part:\n\n")
         tmp <- data.frame(as.list(object@internal$sam.struc.fit))
