@@ -382,6 +382,17 @@ lavParseModelString <- function(model.syntax = '', as.data.frame. = FALSE,
                         stop("lavaan ERROR: duplicate model element in: ", model[i])
                     }
                 }
+
+                # check if we have a self-loop (y ~ y)
+                if(op %in% c("~", "<~") && rhs.name == lhs.names[l]) {
+                    #stop("lavaan ERROR: lhs and rhs are the same in: ",
+                    #     model[i])
+                    # this breaks pompom package, example uSEM
+                    warning("lavaan WARNING: lhs and rhs are the same in: ",
+                            model[i])
+                }
+
+
                 FLAT.idx <- FLAT.idx + 1L
                 FLAT.lhs[FLAT.idx] <- lhs.names[l]
                 FLAT.op[ FLAT.idx] <- op
@@ -396,7 +407,6 @@ lavParseModelString <- function(model.syntax = '', as.data.frame. = FALSE,
                 FLAT.efa[FLAT.idx]   <- ""
                 FLAT.rv[FLAT.idx]    <- ""
 
-
                 mod <- list()
                 rhs.mod <- 0L
                 if(length(lhs.out[[l]]$efa) > 0L) {
